/*
 * Segment 6 Intelligente Bewertungsverfahren, SWE 6.2 Baustellensimulation
 * Copyright (C) 2007 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.ibv.simbaustelle.migration.modell.verkehr;

import de.bsvrz.ibv.simbaustelle.migration.modell.SystemObjekt;
import de.bsvrz.ibv.simbaustelle.migration.modell.SystemObjektTyp;
import de.bsvrz.ibv.simbaustelle.migration.modell.verkehr.objekte.AeusseresStrassenSegment;
import de.bsvrz.ibv.simbaustelle.migration.modell.verkehr.objekte.Baustelle;
import de.bsvrz.ibv.simbaustelle.migration.modell.verkehr.objekte.FahrStreifen;
import de.bsvrz.ibv.simbaustelle.migration.modell.verkehr.objekte.InneresStrassenSegment;
import de.bsvrz.ibv.simbaustelle.migration.modell.verkehr.objekte.MessQuerschnitt;
import de.bsvrz.ibv.simbaustelle.migration.modell.verkehr.objekte.MessQuerschnittAllgemein;
import de.bsvrz.ibv.simbaustelle.migration.modell.verkehr.objekte.MessQuerschnittVirtuell;
import de.bsvrz.ibv.simbaustelle.migration.modell.verkehr.objekte.Netz;
import de.bsvrz.ibv.simbaustelle.migration.modell.verkehr.objekte.RoutenStueck;
import de.bsvrz.ibv.simbaustelle.migration.modell.verkehr.objekte.StoerfallIndikator;
import de.bsvrz.ibv.simbaustelle.migration.modell.verkehr.objekte.Strasse;
import de.bsvrz.ibv.simbaustelle.migration.modell.verkehr.objekte.StrassenKnoten;
import de.bsvrz.ibv.simbaustelle.migration.modell.verkehr.objekte.StrassenSegment;
import de.bsvrz.ibv.simbaustelle.migration.modell.verkehr.objekte.StrassenTeilSegment;
import de.bsvrz.ibv.simbaustelle.migration.modell.verkehr.objekte.VerkehrModellNetz;

/**
 * Fasst alle Objekttypen im Verkehrsmodell zusammen.
 *
 * @author BitCtrl Systems GmbH, Schumann
 */
public enum VerkehrsModellTypen implements SystemObjektTyp {

	/** Ein &auml;u&szlig;eres Stra&szlig;ensegment. */
	AUESSERES_STRASSENSEGMENT("typ.äußeresStraßenSegment",
			AeusseresStrassenSegment.class),

	/** Ein inneres Stra&szlig;ensegment. */
	INNERES_STRASSENSEGMENT("typ.inneresStraßenSegment",
			InneresStrassenSegment.class),

	/** Ein Messquerschnitt. */
	STOERFALLINDIKATOR("typ.störfallIndikator", StoerfallIndikator.class),

	/** Ein Fahrstreifen. */
	FAHRSTREIFEN("typ.fahrStreifen", FahrStreifen.class),

	/** Ein allgemeiner Messquerschnitt. */
	MESSQUERSCHNITTALLGEMEIN("typ.messQuerschnittAllgemein",
			MessQuerschnittAllgemein.class),

	/** Ein Messquerschnitt. */
	MESSQUERSCHNITT("typ.messQuerschnitt", MessQuerschnitt.class),

	/** Ein virtueller Messquerschnitt. */
	MESSQUERSCHNITTVIRTUELL("typ.messQuerschnittVirtuell",
			MessQuerschnittVirtuell.class),

	/** Ein Netz. */
	NETZ("typ.netz", Netz.class),

	/** Ein Stra&szlig;enknoten. */
	STRASSENKNOTEN("typ.straßenKnoten", StrassenKnoten.class),

	/** Ein Stra&szlig;ensegment. */
	STRASSENSEGMENT("typ.straßenSegment", StrassenSegment.class),

	/** Ein Stra&szlig;enteilsegment. */
	STRASSENTEILSEGMENT("typ.straßenTeilSegment", StrassenTeilSegment.class),

	/** Ein Verkehrsmodellnetz. */
	VERKEHRSMODELLNETZ("typ.verkehrsModellNetz", VerkehrModellNetz.class),

	/** Eine Stra&szlig;e. */
	STRASSE("typ.straße", Strasse.class),

	/** Ein Routenst&uuml;ck. */
	ROUTENSTUECK("typ.routenStück", RoutenStueck.class),

	/** Eine Baustelle. */
	BAUSTELLE("typ.baustelle", Baustelle.class);

	/** PID des Objekttyps im Datenverteiler. */
	private final String pid;

	/** Klasse des Systemobjekts im Modell. */
	private final Class<? extends SystemObjekt> klasse;

	/**
	 * Konstruktor.
	 *
	 * @param pid
	 *            Die PID des Typs
	 * @param klasse
	 *            Die Klasse des Modellobjekts
	 */
	VerkehrsModellTypen(final String pid,
			final Class<? extends SystemObjekt> klasse) {
		this.pid = pid;
		this.klasse = klasse;
	}

	@Override
	public Class<? extends SystemObjekt> getKlasse() {
		return klasse;
	}

	@Override
	public String getPid() {
		return pid;
	}

}
