/*
 * Segment 6 Intelligente Bewertungsverfahren, SWE 6.2 Baustellensimulation
 * Copyright (C) 2007 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.ibv.simbaustelle.parameter;

import java.time.Duration;

/**
 * Schnittstelle zur Implementierung des Moduls zur Überwachung und
 * Bereitstellung der Parameter für die Baustellensimulation an einem
 * VerkehrsmodellNetz.
 *
 * @author BitCtrl Systems GmbH, Peuker
 */
public interface IBssParameterObserver {
	/**
	 * liefert die Dauer des Prognose-Horizonts.
	 *
	 * @return den Horizont
	 */
	Duration getHorizont();

	/**
	 * liefert das Aktualisierungsintervall in Millsekunden.
	 *
	 * @return das Aktualisierungsintervall
	 */
	Duration getAktualisierungsIntervall();

	/**
	 * liefert die Prognoseschrittweite in Millisekunden.
	 *
	 * @return die Progrnoseschrittweite
	 */
	Duration getPrognoseSchrittweite();

	/**
	 * liefert den Faktor für die Anpassung von Q0 aus dem Fundamentaldiagramm
	 * in Prozent.
	 *
	 * @return den Wert in Prozent
	 */
	double getFaktorQ0();

	/**
	 * die Länge eines Fahrzeugs in Zentimetern.
	 *
	 * @return die Länge
	 */
	long getLaengePkw();

	/**
	 * liefert die Länge, ab der bei der Prognose ein Stau angelegt werden soll
	 * in Metern.
	 *
	 * @return die Länge in Metern
	 */
	long getLaengeStauBeginn();

	/**
	 * liefert die Länge, ab der bei der Prognose ein Stau beendet werden soll
	 * in Metern.
	 *
	 * @return die Länge in Metern
	 */
	long getLaengeStauAufhebung();

	/**
	 * fügt der Parameterverwaltung einen Listener hinzu, der benachrichtigt
	 * wird, wenn ein neuer Parameterdatensatz empfangen wurde.
	 *
	 * @param listener
	 *            der neue Listener
	 */
	void addParameterListener(IBssParameterListener listener);

	/**
	 * entfernt von der Parameterverwaltung einen Listener, der benachrichtigt
	 * wurde, wenn ein neuer Parameterdatensatz empfangen wurde.
	 *
	 * @param listener
	 *            der zu entfernende Listener
	 */
	void removeParameterListener(IBssParameterListener listener);
}
